<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2020.1/2030377
 */

namespace Jobs\Model;

use Application\Model\AbstractDAO;
use P4\Spec\Change;

/**
 * Class JobDAO. DAO to access job information
 * @package Jobs\Model
 */
class JobDAO extends AbstractDAO
{
    /**
     * Gets the jobs for a change in the form
     *       [
     *           "job"                  => "job000020",
     *           "link"                 => "/jobs/job000020",
     *           "fixStatus"            => "open",
     *           "description"          => "Need Project files\n",
     *           "description-markdown" => "<span class=\"first-line\">Need Project files</span>"
     *       ]
     * @param Change $change
     * @return array an array of jobs or an empty array if none are found
     */
    public function getJobs(Change $change)
    {
        $jobs = [];
        foreach ($change->getJobObjects() as $job) {
            $jobs[] = [
                IJob::FIELD_JOB         => $job->getId(),
                // Included a link for now, we might find we don't need this in the react implementation
                IJob::FIELD_LINK        => '/jobs/' . $job->getId(),
                IJob::FIELD_FIX_STATUS  => $job->getStatus(),
                IJob::FIELD_DESCRIPTION => $job->getDescription()
            ];
        }
        return $jobs;
    }
}
